# VH15010UNO

**VH15010UNO** es una librería en Python para resolver sistemas de ecuaciones lineales y no lineales utilizando distintos métodos numéricos clásicos.

## Métodos implementados

### Ecuaciones Lineales
- Eliminación de Gauss
- Gauss-Jordan
- Método de Cramer
- Descomposición LU
- Iterativo de Jacobi
- Iterativo de Gauss-Seidel

### Ecuaciones No Lineales
- Método de Bisección


